
dialogId("mik-v-sakra", "font_big", "Dang, that snail is blocking the way.")

dialogId("mik-v-projet", "font_big", "I can’t swim through.")

dialogId("mik-m-krab", "font_small", "Those crabs are too talkative.")

dialogId("mik-m-poust", "font_small", "They don’t look like hermits.")

dialogId("mik-m-tusit", "font_small", "I had no idea that hermit crabs could be so talkative.")

dialogId("mik-v-ticho0", "font_big", "Shut up!")

dialogId("mik-v-ticho1", "font_big", "Silence!")

dialogId("mik-v-ticho2", "font_big", "What is it now?!")

dialogId("mik-v-proto", "font_big", "That’s better.")

dialogId("mik-v-tak", "font_big", "Yes.")

dialogId("mik-m-nezlob", "font_small", "Don’t be mad at them.")

dialogId("mik-m-myslit", "font_small", "Now we can calmly ponder how to get out of here.")

dialogId("mik-m-proc", "font_small", "White fish, why do you have such big eyes?")

dialogId("mik-v-videt", "font_big", "All the better to see you with.")

dialogId("mik-m-konik", "font_small", "I’ve seen this seahorse somewhere before.")

dialogId("mik-x-stebet0", "", "")

dialogId("mik-x-stebet1", "", "")

dialogId("mik-x-stebet2", "", "")

dialogId("mik-x-stebet3", "", "")
